@@ -323,6 +323,10 @@ class CombinedForm(object, metaclass=CombinedFormMetaclass):
         all_forms = ''.join(form.as_p() for form in list(self.values()))
         return utils.safestring.mark_safe(all_forms)
 
+    def items(self):
+        """Iterate over the subform names and subforms"""
+        return self.iteritems()
+
     def iteritems(self):
         """Iterate over the subform names and subforms."""
         return iter((k, self[k]) for k in list(self.keys()))
@@ -363,33 +367,16 @@ class CombinedForm(object, metaclass=CombinedFormMetaclass):
 
     @property
     def cleaned_data(self):
-        """Get a dictionary of cleaned values from all subforms.
+        """Get a nested dictionary of cleaned values from all subforms.
 
-        Values get prefixed with the subform's prefix and a '-'. This is
-        different than a standard Django form, which returns all values
-        without any prefixes.
+        Keys correspond to subform names, and values correspond to that
+        subform's ``cleaned_data`` attribute.
 
-        Raises an exception if the formset is not valid.
+        Will raise an exception if the subform doesn't have a
+        ``cleaned_data`` attribute.
 
         """
-        combined_data = {}
-        for subform_name in self:
-
-            # cleaned data from subforms come back without any prefix, so
-            # manually reattach
-            subform_data = self[subform_name].cleaned_data
-
-            # prefix may be an empty string
-            subform_prefix = getattr(type(self), subform_name).prefix
-
-            if subform_prefix:
-                subform_prefix += '-'
-
-            prefixed_data = {(subform_prefix + k): v for k, v in
-                             subform_data.items()}
-            combined_data.update(prefixed_data)
-
-        return combined_data
+        return {formname: form.cleaned_data for formname, form in self.items()}
 
     @property
     def non_field_errors(self):
